@@ -217,7 +217,9 @@ class AnnotationClassMapper:
             return self.__annotation_class_name_to_model_class_name_map[class_name]
 
         raise ClassMappingNotFoundError(
-            f"Could not find a valid mapping for class-name='{class_name}'"
+            f"Could not find a valid mapping for class-name='{class_name}'. "
+            f"Please add it in the mapping configuration or add it to the configuration list "
+            f"'ignore_class_names' "
         )
 
     def map_annotation_class_name_to_model_class_id(self, class_name: str) -> int:
@@ -242,6 +244,7 @@ class AnnotationClassMapper:
         model_class_name = self.map_annotation_class_name_to_model_class_name(
             class_name=class_name
         )
+
         # Try to find a valid mapping for the given input-key
         if model_class_name in self.__annotation_class_name_to_model_class_id_map:
             return self.__annotation_class_name_to_model_class_id_map[model_class_name]
@@ -413,7 +416,7 @@ class AnnotationClassMapper:
         classes_id_dict: Dict[int, str] = {}
 
         for model_class in class_mapping_config.model_classes:
-            if model_class.class_id > class_mapping_config.get_number_classes():
+            if model_class.class_id >= class_mapping_config.get_number_classes():
                 invalid_class_ids.append(model_class.class_id)
                 continue
 
