@@ -12,6 +12,8 @@ from typing import Any, Dict
 import related
 from config_builder.BaseConfigClass import BaseConfigClass
 
+INIT_FOR_INFERENCE_PARAMETER = "init_for_inference"
+
 
 @related.mutable(strict=True)
 class ModelConfig(BaseConfigClass):
@@ -19,3 +21,10 @@ class ModelConfig(BaseConfigClass):
     constructor_parameters: Dict[str, Any] = related.ChildField(
         cls=dict,
     )
+
+    def is_inference(self) -> bool:
+        return INIT_FOR_INFERENCE_PARAMETER in self.constructor_parameters
+
+    def set_inference(self, inference: bool) -> None:
+        if INIT_FOR_INFERENCE_PARAMETER in self.constructor_parameters:
+            self.constructor_parameters[INIT_FOR_INFERENCE_PARAMETER] = inference
