@@ -13,7 +13,8 @@ import related
 from config_builder.BaseConfigClass import BaseConfigClass
 
 from mlcvzoo_base.api.configuration import Configuration
-from mlcvzoo_base.configuration.AnnotationHandlerConfig import AnnotationHandlerConfig
+from mlcvzoo_base.configuration.annotation_handler_config import AnnotationHandlerConfig
+from mlcvzoo_base.configuration.class_mapping_config import ClassMappingConfig
 from mlcvzoo_base.configuration.detector_configs import DetectorConfig
 from mlcvzoo_base.configuration.reduction_mapping_config import ReductionMappingConfig
 
@@ -24,6 +25,8 @@ class ReadFromFileConfig(BaseConfigClass, Configuration):
 
     mutual_attribute_map: Dict[str, List[str]] = dict()
 
+    class_mapping: ClassMappingConfig = related.ChildField(ClassMappingConfig)
+
     annotation_handler_config: AnnotationHandlerConfig = related.ChildField(
         cls=AnnotationHandlerConfig
     )
@@ -36,6 +39,4 @@ class ReadFromFileConfig(BaseConfigClass, Configuration):
         cls=ReductionMappingConfig, required=False, default=None
     )
 
-    base_config: DetectorConfig = related.ChildField(
-        cls=DetectorConfig, default=DetectorConfig()
-    )
+    base_config: DetectorConfig = related.ChildField(cls=DetectorConfig, default=DetectorConfig())
