@@ -15,6 +15,7 @@ import cv2
 from nptyping import Int, NDArray, Shape
 
 from mlcvzoo_base.api.data.annotation import BaseAnnotation
+from mlcvzoo_base.api.data.annotation_class_mapper import AnnotationClassMapper
 from mlcvzoo_base.api.data.bounding_box import BoundingBox
 from mlcvzoo_base.api.data.classification import Classification
 from mlcvzoo_base.api.data.segmentation import Segmentation
@@ -28,7 +29,7 @@ from mlcvzoo_base.api.model import (
 from mlcvzoo_base.configuration.utils import (
     create_configuration as create_basis_configuration,
 )
-from mlcvzoo_base.data_preparation.AnnotationHandler import AnnotationHandler
+from mlcvzoo_base.data_preparation.annotation_handler import AnnotationHandler
 from mlcvzoo_base.models.read_from_file.configuration import ReadFromFileConfig
 
 logger = logging.getLogger(__name__)
@@ -78,25 +79,40 @@ class ReadFromFileModel(
             configuration=configuration,
             string_replacement_map=string_replacement_map,
         )
-
-        self.annotation_handler = AnnotationHandler(
-            configuration=self.configuration.annotation_handler_config,
-            string_replacement_map=string_replacement_map,
-        )
-
-        self.annotations_dict: Dict[
-            str, BaseAnnotation
-        ] = self.initialize_annotations_dict(
-            annotations=self.annotation_handler.parse_from_all_source()
-        )
-
         Model.__init__(
             self,
             unique_name=os.path.basename(from_yaml).replace(".yaml", ""),
             configuration=self.configuration,
+            init_for_inference=True,
+        )
+        Classifiable.__init__(
+            self,
+            mapper=AnnotationClassMapper(
+                class_mapping=self.configuration.class_mapping,
+                reduction_mapping=self.configuration.reduction_class_mapping,
+            ),
         )
 
-        self.get_name()
+        if self.configuration.annotation_handler_config.class_mapping is not None:
+            logger.warning(
+                "Explicit annotation_handler_config.class_mapping is not "
+                "supported in a models context anymore!"
+            )
+
+        if self.configuration.annotation_handler_config.reduction_class_mapping is not None:
+            logger.warning(
+                "Explicit annotation_handler_config.reduction_class_mapping is not "
+                "supported in a models context anymore!"
+            )
+
+        self.annotation_handler = AnnotationHandler(
+            mapper=self.mapper,
+            configuration=self.configuration.annotation_handler_config,
+        )
+
+        self.annotations_dict: Dict[str, BaseAnnotation] = self.initialize_annotations_dict(
+            annotations=self.annotation_handler.parse_inference_annotations()
+        )
 
     @staticmethod
     def create_configuration(
@@ -119,9 +135,7 @@ class ReadFromFileModel(
         return self.annotation_handler.mapper.num_classes
 
     def get_classes_id_dict(self) -> Dict[int, str]:
-        return (
-            self.annotation_handler.mapper.annotation_class_id_to_model_class_name_map
-        )
+        return self.annotation_handler.mapper.annotation_class_id_to_model_class_name_map
 
     @staticmethod
     def create_image_hash(data_item: Union[str, ImageType]) -> str:
@@ -136,13 +150,13 @@ class ReadFromFileModel(
         self, annotations: List[BaseAnnotation]
     ) -> Dict[str, BaseAnnotation]:
         """
-        TODO:
+        Create a hashed annotation dictionary from a given list of annotations
 
         Args:
-            annotations:
+            annotations: list of annotations
 
         Returns:
-
+            a hashed dict with annotations
         """
         annotations_dict: Dict[str, BaseAnnotation] = {}
 
@@ -160,9 +174,7 @@ class ReadFromFileModel(
                 ] = annotation
             else:
                 annotations_dict[annotation.image_path] = annotation
-                annotations_dict[
-                    self.create_image_hash(annotation.image_path)
-                ] = annotation
+                annotations_dict[self.create_image_hash(annotation.image_path)] = annotation
 
         return annotations_dict
 
@@ -187,6 +199,8 @@ class ReadFromFileClassificationModel(
             self,
             unique_name=os.path.basename(from_yaml).replace(".yaml", ""),
             configuration=self.configuration,
+            mapper=self.mapper,
+            init_for_inference=True,
         )
 
     def predict(
@@ -201,9 +215,7 @@ class ReadFromFileClassificationModel(
             classifications = self.annotations_dict[data_hash].classifications
             return data_item, classifications
 
-        raise ValueError(
-            "data_item='%s' not in lookup dict of the ReadFromFileModel" % data_item
-        )
+        raise ValueError("data_item='%s' not in lookup dict of the ReadFromFileModel" % data_item)
 
 
 class ReadFromFileObjectDetectionModel(
@@ -226,6 +238,8 @@ class ReadFromFileObjectDetectionModel(
             self,
             unique_name=os.path.basename(from_yaml).replace(".yaml", ""),
             configuration=self.configuration,
+            mapper=self.mapper,
+            init_for_inference=True,
         )
 
     def predict(
@@ -245,9 +259,7 @@ class ReadFromFileObjectDetectionModel(
             )
             return data_item, bounding_boxes
 
-        raise ValueError(
-            "data_item='%s' not in lookup dict of the ReadFromFileModel" % data_item
-        )
+        raise ValueError("data_item='%s' not in lookup dict of the ReadFromFileModel" % data_item)
 
 
 class ReadFromFileSegmentationModel(
@@ -270,6 +282,8 @@ class ReadFromFileSegmentationModel(
             self,
             unique_name=os.path.basename(from_yaml).replace(".yaml", ""),
             configuration=self.configuration,
+            mapper=self.mapper,
+            init_for_inference=True,
         )
 
     def predict(
@@ -286,6 +300,4 @@ class ReadFromFileSegmentationModel(
 
             return data_item, segmentations
 
-        raise ValueError(
-            "data_item='%s' not in lookup dict of the ReadFromFileModel" % data_item
-        )
+        raise ValueError("data_item='%s' not in lookup dict of the ReadFromFileModel" % data_item)
