@@ -46,9 +46,7 @@ def _scale_frame(
             int(frame.shape[0] * scale_factor),
         )
 
-        scaled_frame = cv2.resize(
-            scaled_frame, resize_shape, interpolation=cv2.INTER_AREA
-        )
+        scaled_frame = cv2.resize(scaled_frame, resize_shape, interpolation=cv2.INTER_AREA)
         return scaled_frame, resize_shape
     else:
         return frame, (frame.shape[1], frame.shape[0])
@@ -87,9 +85,7 @@ class VideoLiveOutput:
         self.mode = VideoLiveOutput.MODE_STEP
         if mode is not None:
             if mode not in self.MODES:
-                raise ValueError(
-                    "Invalid mode='%s' has to be one of '%s'" % (mode, self.MODES)
-                )
+                raise ValueError("Invalid mode='%s' has to be one of '%s'" % (mode, self.MODES))
 
             self.mode = mode
         self.frame = 0
@@ -405,9 +401,7 @@ class VideoFileOutput:
 
             logger.info("Open VideoWriter for video-path: %s", self.path)
 
-            scaled_frame, resize_shape = _scale_frame(
-                frame=frame, output_shape=self.output_shape
-            )
+            scaled_frame, resize_shape = _scale_frame(frame=frame, output_shape=self.output_shape)
 
             self.video_writer = cv2.VideoWriter(
                 filename=self.path,
@@ -434,9 +428,7 @@ class VideoFileOutput:
                 lineType=cv2.LINE_AA,
             )
 
-        scaled_frame, resize_shape = _scale_frame(
-            frame=frame, output_shape=self.output_shape
-        )
+        scaled_frame, resize_shape = _scale_frame(frame=frame, output_shape=self.output_shape)
         self.video_writer.write(scaled_frame)
 
     def close(self) -> None:
